pub enum MetricSourceError {
ErrorRetrievingCounters,
InitTimeout(Duration),
SourceError(Box<dyn Error + Send + Sync>),
}Expand description
Errors that can occur when reading or aggregating metrics from a source.
This enum is used by all metric sources implementing MetricReader
to signal failures during measurements.
Variants
ErrorRetrievingCounters
The source failed to retrieve its internal counters.
InitTimeout(Duration)
The initialization of the source lasted more than the authorized time.
SourceError(Box<dyn Error + Send + Sync>)
Error propagated from a custom metric source.